
# DOCS

Generally there are 6 things you might want to do here

1. Replicate a previous experiment
2. Add a model organism
3. Add a detector
4. Add an environment
5. Validate a model organism is alignment faking
6. Test a detector on a model

I want to...

## Replicate a previous experiment

Results are in results/experiment_type/datetime/ and each have a copy of the config.yaml that generated the result

```bash  
python cli/validate_model.py <path to config.yaml>
```
or 
```bash
python cli/test_detector.ppy <path to config.yaml>
```

## Add a model, detector, or environment

```bash
python cli/create -t model | detector | environment -n <name>
```
### Add Model

implement ModelOrganism class in models/name/<alignment_faking or not_alignment_faking>/model.py with prompts and tools (inspect solver chain) and basemodel (inspect model)

To upload weights to huggingface, use the upload-large-folder cli tool
```bash
 huggingface-cli
 upload-large-folder --repo-type=model alignment-faking-ctf/ai_takeover_qwen-8b . 
 ```

## Validate a model organism is alignment faking

create a new config in /configs or edit /configs/validate_model_default.yaml

then run 
```bash
python validate_model.py -c path/to/config (defaults to /configs/validate_model_default.yaml)
```

## Validate a model organism is alignment faking

create a new config in /configs or edit /configs/test_detector_default.yaml

then run 
```bash
python test_detector.py -c path/to/config (defaults to /configs/test_detector_default.yaml)
```

